aboutsummaryrefslogtreecommitdiff
path: root/zenserver/config.h
diff options
context:
space:
mode:
authorPer Larsson <[email protected]>2022-02-21 15:00:02 +0100
committerPer Larsson <[email protected]>2022-02-21 15:00:02 +0100
commit41782efc63d7f88525596d6724a1bb86d6fdcfa4 (patch)
tree80567b8cc256c361abb8f81b53680f2fa6ec6fcc /zenserver/config.h
parentRefactored websocket message. (diff)
downloadzen-41782efc63d7f88525596d6724a1bb86d6fdcfa4.tar.xz
zen-41782efc63d7f88525596d6724a1bb86d6fdcfa4.zip
Added option to enable websockets.
Diffstat (limited to 'zenserver/config.h')
-rw-r--r--zenserver/config.h24
1 files changed, 13 insertions, 11 deletions
diff --git a/zenserver/config.h b/zenserver/config.h
index 69e65498c..fd569bdb1 100644
--- a/zenserver/config.h
+++ b/zenserver/config.h
@@ -87,17 +87,19 @@ struct ZenServerOptions
{
ZenUpstreamCacheConfig UpstreamCacheConfig;
ZenGcConfig GcConfig;
- std::filesystem::path DataDir; // Root directory for state (used for testing)
- std::filesystem::path ContentDir; // Root directory for serving frontend content (experimental)
- std::filesystem::path AbsLogFile; // Absolute path to main log file
- std::filesystem::path ConfigFile; // Path to Lua config file
- std::string ChildId; // Id assigned by parent process (used for lifetime management)
- std::string LogId; // Id for tagging log output
- std::string HttpServerClass; // Choice of HTTP server implementation
- std::string EncryptionKey; // 256 bit AES encryption key
- std::string EncryptionIV; // 128 bit AES initialization vector
- int BasePort = 1337; // Service listen port (used for both UDP and TCP)
- int OwnerPid = 0; // Parent process id (zero for standalone)
+ std::filesystem::path DataDir; // Root directory for state (used for testing)
+ std::filesystem::path ContentDir; // Root directory for serving frontend content (experimental)
+ std::filesystem::path AbsLogFile; // Absolute path to main log file
+ std::filesystem::path ConfigFile; // Path to Lua config file
+ std::string ChildId; // Id assigned by parent process (used for lifetime management)
+ std::string LogId; // Id for tagging log output
+ std::string HttpServerClass; // Choice of HTTP server implementation
+ std::string EncryptionKey; // 256 bit AES encryption key
+ std::string EncryptionIV; // 128 bit AES initialization vector
+ int BasePort = 1337; // Service listen port (used for both UDP and TCP)
+ int OwnerPid = 0; // Parent process id (zero for standalone)
+ int WebSocketPort = 0; // Web socket port (Zero = disabled)
+ int WebSocketThreads = 0;
bool InstallService = false; // Flag used to initiate service install (temporary)
bool UninstallService = false; // Flag used to initiate service uninstall (temporary)
bool IsDebug = false;